@@ -18,7 +18,6 @@ char *fake = N_("Tolerance for InfiniteSum and InfiniteProduct");
 char *fake = N_("Absolute value");
 char *fake = N_("Replace very small number with zero");
 char *fake = N_("Return the fractional part of a number");
-char *fake = N_("Division w/o remainder");
 char *fake = N_("Return the sign (-1,0,1)");
 char *fake = N_("Logarithm of any base (calls DiscreteLog if in modulo mode), if base is not given, e is used");
 char *fake = N_("The arccos (inverse cos) function");
@@ -45,10 +44,10 @@ char *fake = N_("Find the x that solves the system given by the vector a and mod
 char *fake = N_("Given two factorizations, give the factorization of the product, see Factorize");
 char *fake = N_("Convert a vector of values indicating powers of b to a number");
 char *fake = N_("Convert a number to a vector of powers for elements in base b");
-char *fake = N_("Find discrete log of n base b in F_q where q is a prime using the Silver-Pohlig-Hellman algoritm");
+char *fake = N_("Find discrete log of n base b in F_q where q is a prime using the Silver-Pohlig-Hellman algorithm");
 char *fake = N_("Compute phi(n), the Euler phi function, that is the number of integers between 1 and n relatively prime to n");
 char *fake = N_("Return all factors of a number");
-char *fake = N_("Attempt fermat factorization of n into (t-s)*(t+s), returns t and s as a vector if possible, null otherwise");
+char *fake = N_("Attempt Fermat factorization of n into (t-s)*(t+s), returns t and s as a vector if possible, null otherwise");
 char *fake = N_("Find the first primitive element in F_q (q must be a prime)");
 char *fake = N_("Find a random primitive element in F_q (q must be a prime)");
 char *fake = N_("Compute discrete log base b of n in F_q (q a prime) using the factor base S.  S should be a column of primes possibly with second column precalculated by IndexCalculusPrecalculation.");
@@ -67,9 +66,9 @@ char *fake = N_("Return the Moebius mu function evaluated in n");
 char *fake = N_("Returns the p-adic valuation (number of trailing zeros in base p).");
 char *fake = N_("Compute a^b mod m");
 char *fake = N_("Return all prime factors of a number");
-char *fake = N_("Pseudoprime test, true iff b^(n-1) == 1 (mod n)");
+char *fake = N_("Pseudoprime test, true if and only if b^(n-1) == 1 (mod n)");
 char *fake = N_("Removes all instances of the factor m from the number n");
-char *fake = N_("Find discrete log of n base b in F_q where q is a prime using the Silver-Pohlig-Hellman algoritm, given f being the factorization of q-1");
+char *fake = N_("Find discrete log of n base b in F_q where q is a prime using the Silver-Pohlig-Hellman algorithm, given f being the factorization of q-1");
 char *fake = N_("Find square root of n mod p (a prime). Null is returned if not a quadratic residue.");
 char *fake = N_("Apply a function over all entries of a matrix and return a matrix of the results");
 char *fake = N_("Apply a function over all entries of 2 matrices (or 1 value and 1 matrix) and return a matrix of the results");
@@ -88,6 +87,7 @@ char *fake = N_("Get the outer product of two vectors");
 char *fake = N_("Reverse elements in a vector");
 char *fake = N_("Calculate sum of each row in a matrix");
 char *fake = N_("Calculate sum of squares of each row in a matrix");
+char *fake = N_("Shuffle elements in a vector");
 char *fake = N_("Sort vector elements");
 char *fake = N_("Removes any all-zero rows of M");
 char *fake = N_("Return column(s) and row(s) from a matrix");
@@ -119,14 +119,14 @@ char *fake = N_("Get the invariant factors of a square integer matrix (not its c
 char *fake = N_("Inverse Hilbert matrix of order n");
 char *fake = N_("Is a matrix Hermitian");
 char *fake = N_("Test if a vector is in a subspace");
-char *fake = N_("Is a matrix (or number) invertible (Integer matrix is invertible iff it's invertible over the integers)");
+char *fake = N_("Is a matrix (or number) invertible (Integer matrix is invertible if and only if it is invertible over the integers)");
 char *fake = N_("Is a matrix (or number) invertible over a field");
 char *fake = N_("Is a matrix normal");
 char *fake = N_("Is a matrix positive definite");
 char *fake = N_("Is a matrix positive semidefinite");
 char *fake = N_("Is a matrix skew-Hermitian");
 char *fake = N_("Is a matrix unitary");
-char *fake = N_("Get the jordan block corresponding to lambda and n");
+char *fake = N_("Get the Jordan block corresponding to lambda and n");
 char *fake = N_("Get the kernel (nullspace) of a linear transform");
 char *fake = N_("Get the LU decomposition of A and store the result in the L and U which should be references.  If not possible returns false.");
 char *fake = N_("Get the i-j minor of a matrix");
@@ -159,19 +159,19 @@ char *fake = N_("Intersection of the subspaces given by M and N");
 char *fake = N_("The sum of the vector spaces M and N, that is {w | w=m+n, m in M, n in N}");
 char *fake = N_("Get the classical adjoint (adjugate) of a matrix");
 char *fake = N_("Compute the Column Reduced Echelon Form");
-char *fake = N_("Get n'th catalan number");
+char *fake = N_("Get nth Catalan number");
 char *fake = N_("Double factorial: n(n-2)(n-4)...");
 char *fake = N_("Factorial: n(n-1)(n-2)...");
 char *fake = N_("Falling factorial: (n)_k = n(n-1)...(n-(k-1))");
-char *fake = N_("Calculate n'th Fibonacci number");
+char *fake = N_("Calculate nth Fibonacci number");
 char *fake = N_("Calculate the Frobenius number for a coin problem");
 char *fake = N_("Galois matrix given a linear combining rule (a_1*x_+...+a_n*x_n=x_(n+1))");
 char *fake = N_("Use greedy algorithm to find c, for c . v = n.  (v must be sorted)");
 char *fake = N_("Harmonic Number, the nth harmonic number of order r");
 char *fake = N_("Hofstadter's function q(n) defined by q(1)=1, q(2)=1, q(n)=q(n-q(n-1))+q(n-q(n-2))");
-char *fake = N_("Compute linear recursive sequence using galois stepping");
+char *fake = N_("Compute linear recursive sequence using Galois stepping");
 char *fake = N_("Calculate multinomial coefficients");
-char *fake = N_("Get the pascal's triangle as a matrix");
+char *fake = N_("Get the Pascal's triangle as a matrix");
 char *fake = N_("(Pochhammer) Rising factorial: (n)_k = n(n+1)...(n+(k-1))");
 char *fake = N_("Stirling number of the first kind");
 char *fake = N_("Stirling number of the second kind");
@@ -211,10 +211,10 @@ char *fake = N_("Compute two-sided derivative using five-point formula");
 char *fake = N_("Compute two-sided derivative using three-point formula");
 char *fake = N_("argument (angle) of complex number");
 char *fake = N_("Dirichlet kernel of order n");
-char *fake = N_("Returns 1 iff all elements are zero");
+char *fake = N_("Returns 1 if and only if all elements are zero");
 char *fake = N_("The error function, 2/sqrt(pi) * int_0^x e^(-t^2) dt");
 char *fake = N_("Fejer kernel of order n");
-char *fake = N_("Returns 1 iff all elements are equal");
+char *fake = N_("Returns 1 if and only if all elements are equal");
 char *fake = N_("Find the first value where f(x)=0");
 char *fake = N_("Moebius mapping of the disk to itself mapping a to 0");
 char *fake = N_("Moebius mapping using the cross ratio taking z2,z3,z4 to 1,0, and infinity respectively");
@@ -230,10 +230,10 @@ char *fake = N_("Convert radians to degrees");
 char *fake = N_("Find roots of a cubic polynomial (given as vector of coefficients)");
 char *fake = N_("Use classical Euler's method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns y at x1");
 char *fake = N_("Use classical Euler's method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns an n+1 by 2 matrix of values");
-char *fake = N_("Find root of a function using the bisection method");
-char *fake = N_("Find root of a function using the method of false position");
+char *fake = N_("Find root of a function using the bisection method to within TOL tolerance in up to N iterations.  f(a) and f(b) must have opposite signs.");
+char *fake = N_("Find root of a function using the method of false position to within TOL tolerance in up to N iterations.  f(a) and f(b) must have opposite signs.");
 char *fake = N_("Find root of a function using the Muller's method");
-char *fake = N_("Find root of a function using the secant method");
+char *fake = N_("Find root of a function using the secant method to within TOL tolerance in up to N iterations.  f(a) and f(b) must have opposite signs.");
 char *fake = N_("Find roots of a polynomial (given as vector of coefficients)");
 char *fake = N_("Find roots of a quartic polynomial (given as vector of coefficients)");
 char *fake = N_("Use classical non-adaptive Runge-Kutta of fourth order method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns y at x1");
@@ -251,6 +251,9 @@ char *fake = N_("Calculate the standard deviation of a whole matrix");
 char *fake = N_("Run newton's method on a polynomial to attempt to find a root, returns after two successive values are within epsilon or after maxn tries (then returns null)");
 char *fake = N_("Returns a set where every element of X appears only once");
 char *fake = N_("Returns a set theoretic union of X and Y (X and Y are vectors pretending to be sets)");
+char *fake = N_("For a Hilbert function that is c for degree d, given the Macaulay bound for the Hilbert function of degree d+1 (The c^<d> operator from Green's proof)");
+char *fake = N_("The c_<d> operator from Green's proof of Macaulay's Theorem");
+char *fake = N_("Return the dth Macaulay representation of a positive integer c");
 char *fake = N_("Attempt to symbolically differentiate a function n times");
 char *fake = N_("Attempt to symbolically differentiate a function n times quietly and return null on failure");
-char *fake = N_("Attempt to construct the taylor approximation function around x0 to the nth degree.");
+char *fake = N_("Attempt to construct the Taylor approximation function around x0 to the nth degree.");
