@@ -1,5 +1,5 @@
 /* GENIUS Calculator
- * Copyright (C) 1997-2009 Jiri (George) Lebl
+ * Copyright (C) 1997-2013 Jiri (George) Lebl
  *
  * Author: Jiri (George) Lebl
  *
@@ -29,7 +29,7 @@
 
 #include "structs.h"
 
-#define GENIUS_COPYRIGHT_STRING "Copyright (C) 1997-2009 Jiří (George) Lebl, Ph.D."
+#define GENIUS_COPYRIGHT_STRING N_("Copyright (C) 1997-2013 Jiří (George) Lebl")
 
 typedef enum {
 	GEL_NO_ERROR = 0,
@@ -115,6 +115,9 @@ void gel_call_help (const char *function);
 /* implemented in the frontend (query can be NULL) */
 char *gel_ask_string (const char *query, const char *def);
 
+/* implemented in the frontend, buttons should be a nonempty list of strings */
+int gel_ask_buttons (const char *query, GSList *buttonlist);
+
 void gel_help_on (const char *text);
 
 /*these are parts of the above*/
